.TH sane-umax 5 "11 June 1997"
.IX sane-umax
.SH NAME
sane-umax - SANE backend for Umax scanners
.SH DESCRIPTION
The
.B sane-umax
library implements a SANE (Scanner Access Now Easy) backend that
provides access to some Umax scanners.  At present, the following
scanners are known positively to work with this backend, at least a bit:
.PP
.RS
SCSI id:         Remark
.br
--------------  -----------
.br
Vista-S6         all modes
.br
Vista-S6E        all modes, RGB only in preview
.br
UMAX S-6E        all modes, RGB only in preview
.br
UMAX S-6EG       all modes, RGB only in preview
.br
Vista-S8         don't know, please mail
.br
UMAX S-12        all modes
.br
UMAX S-12G       all modes
.br
SuperVista S-12  all modes
.br
PSD              all modes
.br
PL-II            don't know, please mail
.br
Astra 600S       don't know, please mail
.br
UC630            works a bit, please mail
.br
UG630            don't know, please mail
.RE
.PP
If you own a Umax scanner other than the ones
listed above, it will not work with sane! Please try the command-line
version of the umax-driver - if you don't have it, you can download it from
.br
tsx-11.mit.edu /pub/linux/ALPHA/scanner
.br
and if that works mail us so that it will be supported for sane.

.SH "DEVICE NAMES"
This backend expects device names of the form:
.PP
.RS
.IR special
.RE
.PP
Where
.I special
is the UNIX path-name for the special device that corresponds to the
scanner.  The special device name must be a generic SCSI device or a
symlink to such a device.  Under Linux, such a device name could be
.IR /dev/sga
or
.IR /dev/sge ,
for example.
.SH CONFIGURATION
The configuration file for this backend resides in
.IR @CONFIGDIR@/umax.conf .
Its contents is a list of device names that correspond to UMAX
scanners.  Empty lines and lines starting with a hash mark (#) are
ignored.  A sample configuration file is shown below:
.PP
.RS
/dev/scanner
.br
# this is a comment
.br
/dev/sge
.RE
.SH SCSI ADAPTER TIPS
To keep scanning times to a minimum, it is strongly recommended to use
a large buffer size for the generic SCSI driver.  For example, under
Linux the system uses a buffer of size 32KB by default.  This works
but is about a factor of four slower than when using a size of 128KB.
For Linux, the size of this buffer is defined by macro
.B SG_BIG_BUFF
in header file
.IR /usr/include/scsi/sg.h .
After increasing this value to, say, (128*1024=131072), it is necessary to
recompile the kernel/modules and the Umax backend.
.PP
SCSI adapters:
.PP
.RS
.TP
The SCSI-adapters that are shipped with some Umax-scanner are not
supported by Linux and other systems too, so you need another
SCSI-adapter. For that have a look at the howtos and faqs.
.TP
ncr810
When using this controller, be sure to configure the kernel such that
tagged command queueing is disabled, targets are not allowed to
disconnect, and make sure the SCSI timeout is reasonably big; the
default timeout for the Linux 2.0 kernels is 10 seconds, which is way too
low when scanning large area.
.RE
.PP
In general, we recommend to buy a separate (cheap) SCSI card for the
Umax scanners (such as an ncr810 based card).  Otherwise, the
devices on the same SCSI bus as the scanner cannot be accessed while a
scan is in progress.
.SH FILES
.TP
.I @CONFIGDIR@/umax.conf
The backend configuration file.
.TP
.I @LIBDIR@/libsane-umax.a
The static library implementing this backend.
.TP
.I @LIBDIR@/libsane-umax.so
The shared library implementing this backend (present on systems that
support dynamic loading).
.SH ENVIRONMENT
.TP
.B SANE_DEBUG_UMAX
If the library was compiled with debug support enabled, this
environment variable controls the debug level for this backend.  E.g.,
a value of 128 requests all debug output to be printed.  Smaller
levels reduce verbosity. E.g. just say:
.br
export SANE_DEBUG_UMAX=128

.TP
.B SANE_SANEI_SCSI
If the library was compiled with debug support enabled, this
environment variable controls the debug level for the generic SCSI I/O
subsystem.  E.g., a value of 128 requests all debug output to be
printed.  Smaller levels reduce verbosity.
.SH AUTHOR
Oliver Rauch, parts of the low-level-driver by Michael K. Johnson,
parts of this texts by ohters
.SH BUGS
May be a lot ;-(
.br
quality calibration will hang the scanner and the SCSI-bus
.br
highlight, shadow, brightness and contrast don't work at least at
some scanners.
.br
some scanners only work in color-mode, if preview-bit is set
.br
large images are not scanned correct
