/* --------------------------------------------------------------------- */

/* umax.h - umax headerfile for interface for Scanner Access Now Easy.
 *
 * Version 0.5.5
 *
 */

/* --------------------------------------------------------------------- */

#ifndef umax_h
#define umax_h

#include "sys/types.h"
#include "umax-struct.h"


enum Umax_Option
{
    OPT_NUM_OPTS = 0,

    OPT_MODE_GROUP,
    OPT_MODE,
    OPT_RESOLUTION,
    OPT_SOURCE,
    OPT_NEGATIVE,
    OPT_QUALITY,

    OPT_GEOMETRY_GROUP,
    OPT_TL_X,			/* top-left x */
    OPT_TL_Y,			/* top-left y */
    OPT_BR_X,			/* bottom-right x */
    OPT_BR_Y,			/* bottom-right y */

    OPT_ENHANCEMENT_GROUP,
    OPT_ANALOG_GAMMA_BIND,
    OPT_ANALOG_GAMMA,
    OPT_ANALOG_GAMMA_R,
    OPT_ANALOG_GAMMA_G,
    OPT_ANALOG_GAMMA_B,
    OPT_BRIGHTNESS,
    OPT_CONTRAST,
    OPT_THRESHOLD,
    OPT_HIGHLIGHT,
    OPT_SHADOW,

    OPT_CUSTOM_GAMMA,		/* use custom gamma tables? */
    /* The gamma vectors MUST appear in the order gray, red, green,
       blue.  */
    OPT_GAMMA_VECTOR,
    OPT_GAMMA_VECTOR_R,
    OPT_GAMMA_VECTOR_G,
    OPT_GAMMA_VECTOR_B,
    OPT_HALFTONE_DIMENSION,
    OPT_HALFTONE_PATTERN,

    OPT_ADVANCED_GROUP,
    OPT_SLOW,
    OPT_SMEAR,

    /* must come last: */
    NUM_OPTIONS
};


typedef union
{
    SANE_Word   w;
    SANE_Word   *wa;		/* word array */
    SANE_String s;
}
Option_Value;


typedef struct Umax_Device
{
    struct Umax_Device *next;
    SANE_Device sane;
    SANE_Range  dpi_range;
    SANE_Range  x_range;
    SANE_Range  y_range;
    SANE_Range  analog_gamma_range;
    unsigned    flags;
    US          us;
}
Umax_Device;


typedef struct Umax_Scanner
{
    struct Umax_Scanner *next;
    Umax_Device         *device;

    SANE_Option_Descriptor  opt[NUM_OPTIONS];
    Option_Value        val[NUM_OPTIONS];
    SANE_Int            gamma_table[4][256];
    SANE_Int            halftone_pattern[64];

    int                 scanning;
    int                 pass;
    int                 line;
    SANE_Parameters     params;

    pid_t               reader_pid;
    int                 pipe;
}
Umax_Scanner;

#endif /* umax-sane_h */
